
from .advanced import Advanced
from .utilities import Utilities
from .users import Users
from .auth import Auth
from .messages import Messages
from .chats import Chats
from .groups import Groups
from .decorators import Decorators
from .contacts import Contacts
from .settings import Settings
from .stickers import Stickers
from .channels import Channels
from .extras import Exctras
from .gif import Gifs
from .voice_chat import VoiceCall
from .links import Links
from .live import Lives


class Methods(
    Advanced,
    Utilities,
    Users,
    Auth,
    Messages,
    Chats,
    Groups,
    Decorators,
    Contacts,
    Settings,
    Stickers,
    Channels,
    Exctras,
    Gifs,
    VoiceCall,
    Links,
    Lives
):
    pass
